@@ -59,7 +59,7 @@ class NewResultPage : public QWizardPage
 {
     Q_OBJECT
 public:
-    explicit NewResultPage(QWidget *parent = Q_NULLPTR);
+    explicit NewResultPage(QWidget *parent = nullptr);
     ~NewResultPage();
 
     void setTaskCollection(const std::shared_ptr<TaskCollection> &coll);
