@@ -107,7 +107,7 @@ static QStringList fs_intersect(QStringList l1, QStringList l2)
 static QList<QRegExp> get_patterns(const std::vector< std::shared_ptr<ChecksumDefinition> > &checksumDefinitions)
 {
     QList<QRegExp> result;
-    Q_FOREACH (const std::shared_ptr<ChecksumDefinition> &cd, checksumDefinitions)
+    for (const std::shared_ptr<ChecksumDefinition> &cd : checksumDefinitions)
         if (cd)
             Q_FOREACH (const QString &pattern, cd->patterns()) {
                 result.push_back(QRegExp(pattern, fs_cs));
@@ -161,7 +161,7 @@ private:
 
         if (!errors.empty())
             q->setLastError(gpg_error(GPG_ERR_GENERAL),
-                            errors.join(QStringLiteral("\n")));
+                            errors.join(QLatin1Char('\n')));
         q->emitDoneOrError();
     }
 
@@ -292,7 +292,7 @@ static QString decode(const QString &encoded)
     QString decoded;
     decoded.reserve(encoded.size());
     bool shift = false;
-    Q_FOREACH (const QChar ch, encoded)
+    for (const QChar &ch : encoded)
         if (shift) {
             switch (ch.toLatin1()) {
             case '\\': decoded += QLatin1Char('\\'); break;
@@ -339,7 +339,7 @@ static std::vector<File> parse_sum_file(const QString &fileName)
 static quint64 aggregate_size(const QDir &dir, const QStringList &files)
 {
     quint64 n = 0;
-    Q_FOREACH (const QString &file, files) {
+    for (const QString &file : files) {
         n += QFileInfo(dir.absoluteFilePath(file)).size();
     }
     return n;
@@ -348,7 +348,7 @@ static quint64 aggregate_size(const QDir &dir, const QStringList &files)
 static std::shared_ptr<ChecksumDefinition> filename2definition(const QString &fileName,
         const std::vector< std::shared_ptr<ChecksumDefinition> > &checksumDefinitions)
 {
-    Q_FOREACH (const std::shared_ptr<ChecksumDefinition> &cd, checksumDefinitions)
+    for (const std::shared_ptr<ChecksumDefinition> &cd : checksumDefinitions)
         if (cd)
             Q_FOREACH (const QString &pattern, cd->patterns())
                 if (QRegExp(pattern, fs_cs).exactMatch(fileName)) {
@@ -381,7 +381,7 @@ struct sumfile_contains_file : std::unary_function<QString, bool> {
         const std::vector<File> files = parse_sum_file(dir.absoluteFilePath(sumFile));
         qCDebug(KLEOPATRA_LOG) << "find_sums_by_input_files:      found " << files.size()
                                << " files listed in " << qPrintable(dir.absoluteFilePath(sumFile));
-        Q_FOREACH (const File &file, files) {
+        for (const File &file : files) {
             const bool isSameFileName = (QString::compare(file.name, fileName, fs_cs) == 0);
             qCDebug(KLEOPATRA_LOG) << "find_sums_by_input_files:        "
                                    << qPrintable(file.name) << " == "
@@ -413,7 +413,7 @@ static QStringList find_base_directiories(const QStringList &files)
     // Step 1: find base dirs:
 
     std::set<QDir, less_dir> dirs;
-    Q_FOREACH (const QString &file, files) {
+    for (const QString &file : files) {
         const QFileInfo fi(file);
         const QDir dir = fi.isDir() ? QDir(file) : fi.dir();
         dirs.insert(dir);
@@ -652,7 +652,7 @@ void VerifyChecksumsController::Private::run()
 
     const std::vector<SumFile> sumfiles = find_sums_by_input_files(files, errors, progressCb, checksumDefinitions);
 
-    Q_FOREACH (const SumFile &sumfile, sumfiles) {
+    for (const SumFile &sumfile : sumfiles) {
         qCDebug(KLEOPATRA_LOG) << sumfile;
     }
 
