@@ -76,8 +76,8 @@ class Page : public Kleo::KeyTreeView
     Q_OBJECT
     Page(const Page &other);
 public:
-    Page(const QString &title, const QString &id, const QString &text, AbstractKeyListSortFilterProxyModel *proxy = 0, const QString &toolTip = QString(), QWidget *parent = Q_NULLPTR);
-    Page(const KConfigGroup &group, QWidget *parent = Q_NULLPTR);
+    Page(const QString &title, const QString &id, const QString &text, AbstractKeyListSortFilterProxyModel *proxy = nullptr, const QString &toolTip = QString(), QWidget *parent = nullptr);
+    Page(const KConfigGroup &group, QWidget *parent = nullptr);
     ~Page();
 
     void setTemporary(bool temporary);
@@ -100,7 +100,7 @@ public:
     {
         return m_toolTip.isEmpty() ? title() : m_toolTip;
     }
-    void setToolTip(const QString &tip);
+    // not used void setToolTip(const QString &tip);
 
     bool canBeClosed() const
     {
@@ -192,7 +192,7 @@ static const char SORT_DESCENDING[] = "sort-descending";
 Page::Page(const KConfigGroup &group, QWidget *parent)
     : KeyTreeView(group.readEntry(STRING_FILTER_ENTRY),
                   KeyFilterManager::instance()->keyFilterByID(group.readEntry(KEY_FILTER_ENTRY)),
-                  0, parent),
+                  nullptr, parent),
       m_title(group.readEntry(TITLE_ENTRY)),
       m_toolTip(),
       m_isTemporary(false),
@@ -273,6 +273,7 @@ void Page::setTitle(const QString &t)
     }
 }
 
+#if 0 // not used
 void Page::setToolTip(const QString &tip)
 {
     if (tip == m_toolTip) {
@@ -288,6 +289,7 @@ void Page::setToolTip(const QString &tip)
         Q_EMIT titleChanged(title());
     }
 }
+#endif
 
 void Page::setHierarchicalView(bool on)
 {
@@ -432,8 +434,8 @@ private:
 
 TabWidget::Private::Private(TabWidget *qq)
     : q(qq),
-      flatModel(0),
-      hierarchicalModel(0),
+      flatModel(nullptr),
+      hierarchicalModel(nullptr),
       tabWidget(q),
       layout(q),
       actionsCreated(false)
@@ -503,7 +505,7 @@ void TabWidget::Private::slotContextMenu(const QPoint &p)
 void TabWidget::Private::currentIndexChanged(int index)
 {
     const Page *const page = this->page(index);
-    Q_EMIT q->currentViewChanged(page ? page->view() : 0);
+    Q_EMIT q->currentViewChanged(page ? page->view() : nullptr);
     Q_EMIT q->keyFilterChanged(page ? page->keyFilter() : std::shared_ptr<KeyFilter>());
     Q_EMIT q->stringFilterChanged(page ? page->stringFilter() : QString());
     enableDisableCurrentPageActions();
@@ -740,7 +742,7 @@ QAbstractItemView *TabWidget::currentView() const
     if (Page *const page = d->currentPage()) {
         return page->view();
     } else {
-        return 0;
+        return nullptr;
     }
 }
 
@@ -748,11 +750,11 @@ KeyListModelInterface *TabWidget::currentModel() const
 {
     const QAbstractItemView *const view = currentView();
     if (!view) {
-        return Q_NULLPTR;
+        return nullptr;
     }
     QAbstractProxyModel *const proxy = qobject_cast<QAbstractProxyModel *>(view->model());
     if (!proxy) {
-        return Q_NULLPTR;
+        return nullptr;
     }
     return dynamic_cast<KeyListModelInterface *>(proxy);
 }
@@ -798,23 +800,23 @@ void TabWidget::createActions(KActionCollection *coll)
         }, // ### CTRL-W when available
         {
             "window_move_tab_left", i18n("Move Tab Left"), i18n("Move this tab left"),
-            0, this, SLOT(slotMoveCurrentTabLeft()), QStringLiteral("CTRL+SHIFT+LEFT"), false, false
+            nullptr, this, SLOT(slotMoveCurrentTabLeft()), QStringLiteral("CTRL+SHIFT+LEFT"), false, false
         },
         {
             "window_move_tab_right", i18n("Move Tab Right"), i18n("Move this tab right"),
-            0, this, SLOT(slotMoveCurrentTabRight()), QStringLiteral("CTRL+SHIFT+RIGHT"), false, false
+            nullptr, this, SLOT(slotMoveCurrentTabRight()), QStringLiteral("CTRL+SHIFT+RIGHT"), false, false
         },
         {
             "window_view_hierarchical", i18n("Hierarchical Certificate List"), QString(),
-            0, this, SLOT(slotToggleHierarchicalView(bool)), QString(), true, false
+            nullptr, this, SLOT(slotToggleHierarchicalView(bool)), QString(), true, false
         },
         {
             "window_expand_all", i18n("Expand All"), QString(),
-            0, this, SLOT(slotExpandAll()), QStringLiteral("CTRL+."), false, false
+            nullptr, this, SLOT(slotExpandAll()), QStringLiteral("CTRL+."), false, false
         },
         {
             "window_collapse_all", i18n("Collapse All"), QString(),
-            0, this, SLOT(slotCollapseAll()), QStringLiteral("CTRL+,"), false, false
+            nullptr, this, SLOT(slotCollapseAll()), QStringLiteral("CTRL+,"), false, false
         },
     };
 
@@ -827,7 +829,7 @@ void TabWidget::createActions(KActionCollection *coll)
         assert(QString::fromLatin1(ad.name).startsWith(QStringLiteral("window_")));
         ad.name = ad.name + strlen("window_");
         ad.tooltip.clear();
-        ad.receiver = 0;
+        ad.receiver = nullptr;
         ad.shortcut.clear();
         d->otherPageActions[i] = make_action_from_data(ad, coll);
     }
@@ -844,7 +846,7 @@ QAbstractItemView *TabWidget::addView(const QString &title, const QString &id, c
 
 QAbstractItemView *TabWidget::addView(const KConfigGroup &group)
 {
-    return d->addView(new Page(group), 0);
+    return d->addView(new Page(group), nullptr);
 }
 
 QAbstractItemView *TabWidget::addTemporaryView(const QString &title, AbstractKeyListSortFilterProxyModel *proxy, const QString &tabToolTip)
@@ -859,7 +861,7 @@ QAbstractItemView *TabWidget::addTemporaryView(const QString &title, AbstractKey
 QTreeView *TabWidget::Private::addView(Page *page, Page *columnReference)
 {
     if (!page) {
-        return 0;
+        return nullptr;
     }
 
     if (!actionsCreated) {
@@ -915,10 +917,8 @@ void TabWidget::loadViews(const KConfig *config)
         }
     }
     if (!count()) {
-        // add default views:
-        addView(QString(), QStringLiteral("my-certificates"));
-        addView(QString(), QStringLiteral("trusted-certificates"));
-        addView(QString(), QStringLiteral("other-certificates"));
+        // add default view:
+        addView(QString(), QStringLiteral("all-certificates"));
     }
 }
 
